#NCA-->GLM
###
### NCAdata(), NCAcsv() -> for ;NCA only' data input;
### BANOVAdata(), BANOVAcsv() -> for 'statistical analysis only' data input;
### NCA.BANOVAdata(), NCA.BANOVAcsv() for 'NCA -> statistical analysis' data input.
###
NCA.BANOVAdata<-function(replicated=FALSE, parallel=FALSE, multiple=FALSE)
{
cat("\n")

Fname<-Fname

file.menu <- c("Input/edit data from keyboard",
               "Import data file with .csv format",
               "Load data File with .RData format",
               "Back to the top menu",
               "Quit")
cat("\n")

pick <- menu(file.menu, title = " << NCA--> Statistical analysis >> ", graphics=TRUE)
if (pick == 1){
cat("\n")
    if(parallel){
    description_ParaNCAinput()
    TotalSingledata<-data.frame (subj=c(0),drug=c(0),time=c(0), conc=c(0))
    }
    else{
     if(replicated){
       description_RepNCAinput()
       TotalSingledata<-data.frame (subj=c(0),seq=c(0),prd=c(0),drug=c(0),time=c(0), conc=c(0))
       }
       else{
        description_NCAinput()
        TotalSingledata<-data.frame (subj=c(0), seq=c(0),prd=c(0),time=c(0), conc=c(0))
        }
     }
     TotalSingledata<-edit(TotalSingledata)
     ### TotalSingledata<-na.omit(TotalSingledata)     ### for v2.6.1
     show(TotalSingledata)
     cat("\n")
       cat("Enter the file name (no extension!):\n")
        TotalSinglename <-readline()
        TotalSinglename<-paste(TotalSinglename,".RData",sep="")
           if(file.exists(TotalSinglename)){
           cat("\n")
           cat("******************************************\n")
           cat("* The file name have been existed.       *\n")
           cat("* Would you want to overwrite it ? (y/n) *\n")
           cat("******************************************\n")
           ans<-readline()
             if (ans == "y" | ans == "Y")
                {
                saveRDS(TotalSingledata, TotalSinglename)
                cat("\n")
                }
                else{
                cat("\nEnter file name (no extension!):\n")
                TotalSinglename <-readline()
                TotalSinglename<-paste(TotalSinglename,".RData",sep="")
                repeat{
                    if(file.exists(TotalSinglename))
                      {
                      cat("\n")
                      cat("***********************************\n")
                      cat(" The file have been existed.       \n")
                      cat(" Please try another file name.     \n")
                      cat("***********************************\n")
                      TotalSinglename<-readline()
                      TotalSinglename<-paste(TotalSinglename,".RData",sep="")
                      }
                       else{
                       break
                           }
                    }
             }
              saveRDS(TotalSingledata,TotalSinglename)
           }
        else{
           saveRDS(TotalSingledata,TotalSinglename)
          }
          
          Fname<<-TotalSinglename
          ###
          ### now starting checking if the dataset is incomplete data (icd); if it is then stop running;
          ### if it is not, then go to analysis (see icd.check()). 'TotalSingledata' is the first dataset
          ### generated by bear once the raw data has been loaded; same as for NCAcsv().
          ###
          if(parallel){
             if(multiple){
                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
               }
              else{
                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
               }
           }
          else{ 
            if (replicated){
                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=FALSE)
             }
           else{
              if(multiple){
                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
                  }
               else{ 
                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
               } 
            }  
         }
       } 
else {
  if (pick == 2){
      cat("\n")                                          
     if(parallel){
       description_ParaNCAcsv()
      if(multiple){
       return(MultipleParaNCA.MIXcsv())
      }
      else{
      return(ParaNCA.MIXcsv())
       }
     }
     else{ 
      if (replicated){
        description_RepNCAcsv()
        return(RepNCA.MIXcsv())
         }
        else{
        description_NCAcsv()
        if(multiple){
        return(MultipleNCA.BANOVAcsv())
        }
        else{
        return(NCA.BANOVAcsv())
         }
        }   
      }
     }
else {
  if (pick == 3){
     cat("\n")
     description_load()
##     TotalSinglename <-readline() 
##     TotalSinglename<-paste(TotalSinglename,".RData",sep="")
##     load(TotalSinglename)
     TotalSingledata<-readRDS(xx<-file.choose())
     TotalSingledata<-edit(TotalSingledata)
     Fname<<-basename(xx)
     ### TotalSingledata<- na.omit(TotalSingledata)    ### for 2.6.1 
     if(parallel){
      colnames(TotalSingledata)<-list("subj", "drug","time", "conc")
     }
     else{
        if (replicated){
              colnames(TotalSingledata)<-list("subj", "seq", "prd", "drug","time", "conc")
            }
           else{
              colnames(TotalSingledata)<-list("subj", "seq", "prd", "time", "conc")
            }
       }
     cat("\n\n")
     show(TotalSingledata)
     cat("\n\n")
          ###
          ### now starting checking if the dataset is incomplete data (icd); if it is then stop running;
          ### if it is not, then go to analysis (see icd.check()). 'TotalSingledata' is the first dataset
          ### generated by bear once the raw data has been loaded; same as for NCAcsv().
          ###
          if(parallel){
             if(multiple){
                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
               }
              else{
                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
               }
           }
          else{ 
            if (replicated){
                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=FALSE)
             }
           else{
              if(multiple){
                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
                  }
               else{ 
                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
               } 
            }  
         }
      }
  else {
  if (pick == 4){
     graphics.off();cat("\n\n")
     go2menu()
        }  
  else {
  if (pick == 5){
      cat("\n  Thank you for using bear!  Bye now. \n\n")
      graphics.off()
                }
     }
    }
   }
  }
}